Struct
GimpRGB
Description [src]
struct GimpRGB {
gdouble r;
gdouble g;
gdouble b;
gdouble a;
}
Definitions and Functions relating to RGB colors.
Structure members
rThe red component.
gThe green component.
bThe blue component.
aThe alpha component.
Instance methods
gimp_rgba_set
Sets the red, green, blue and alpha components of rgb. The values
should be between 0.0 and 1.0 but there is no check to enforce this
and the values are set exactly as they are passed in.
gimp_rgba_set_uchar
Sets the red, green, blue and alpha components of rgba from 8bit
values (0 to 255).
gimp_rgb_get_uchar
Writes the red, green, blue and alpha components of rgb to the
color components red, green and blue.
gimp_rgb_set
Sets the red, green and blue components of rgb and leaves the
alpha component unchanged. The color values should be between 0.0
and 1.0 but there is no check to enforce this and the values are
set exactly as they are passed in.
gimp_rgb_set_uchar
Sets the red, green and blue components of rgb from 8bit values
(0 to 255) and leaves the alpha component unchanged.